@@ -15,5 +15,8 @@ exp_close_tcl_files() {
 	/* So much for close-on-exec.  Tcl doesn't mark its files that way */
 	/* everything has to be closed explicitly. */
 
+#if 0
+/* Not necessary with Tcl 7.5? */
 	for (i=3; i<tclNumFiles;i++) close(i);
+#endif
 }
