@@ -85,7 +85,7 @@ would appreciate credit if this program or parts of it are used.
 #include "exp_event.h"
 #include "exp_pty.h"
 #ifdef TCL_DEBUGGER
-#include "Dbg.h"
+#include "tcldbg.h"
 #endif
 
 #define SPAWN_ID_VARNAME "spawn_id"
@@ -1113,7 +1113,7 @@ when trapping, see below in child half of fork */
 			/* empty */;
 		}
 		if (rc == -1) {
-			errorlog("parent sync byte read: %s\r\n",Tcl_ErrnoMsg(errno));
+			errorlog("parent: sync byte read: %s\r\n",Tcl_ErrnoMsg(errno));
 			exit(-1);
 		}
 
@@ -1127,7 +1127,7 @@ when trapping, see below in child half of fork */
 		debuglog("parent: telling child to go ahead\r\n");
 		wc = write(sync2_fds[1]," ",1);
 		if (wc == -1) {
-			errorlog("parent sync byte write: %s\r\n",Tcl_ErrnoMsg(errno));
+			errorlog("parent: sync byte write: %s\r\n",Tcl_ErrnoMsg(errno));
 			exit(-1);
 		}
 
