@@ -10,6 +10,9 @@ would appreciate credit if this program or parts of it are used.
 
 #include "expect_cf.h"
 #include <stdio.h>
+#ifdef HAVE_INTTYPES_H
+#  include <inttypes.h>
+#endif
 #include <sys/types.h>
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
@@ -68,7 +71,7 @@ extern void TclRegError();
 #endif
 
 #define real_tty_output(x) (((x)==1) || ((x)==exp_dev_tty))
-#define real_tty_input(x)  (((x)==0) || ((x)==exp_dev_tty))
+#define real_tty_input(x) (exp_stdin_is_tty && (((x)==0) || ((x)==exp_dev_tty)))
 
 #define new(x)	(x *)ckalloc(sizeof(x))
 
@@ -214,7 +217,9 @@ int rm_nulls;			/* skip nulls if true */
 				break;
 			}
 
-			if ((*s & 0x7f) == *ks) continue;
+			/* if this is a problem for you, use exp_parity command */
+/*			if ((*s & 0x7f) == *ks) continue;*/
+			if (*s == *ks) continue;
 			if ((*s == '\0') && rm_nulls) {
 				ks--;
 				continue;
@@ -233,7 +238,9 @@ int rm_nulls;			/* skip nulls if true */
 
 		/* known starting char - quick test 'fore lotta work */
 		if (prog->regstart) {
-			if ((*start_search & 0x7f) != prog->regstart) continue;
+			/* if this is a problem for you, use exp_parity command */
+/*			/* if ((*start_search & 0x7f) != prog->regstart) continue; */
+			if (*start_search != prog->regstart) continue;
 		}
 		r = exp_regtry(prog,start_search,match_length);
 		if (r == EXP_MATCH) {
