@@ -37,7 +37,7 @@ int exp_is_debugging = FALSE;
 #define LOGUSER		(loguser || force_stdout)
 /*VARARGS*/
 void
-exp_log EXP_VARARGS_DEF(int,arg1)
+exp_log TCL_VARARGS_DEF(int,arg1)
 /*exp_log(va_alist)*/
 /*va_dcl*/
 {
@@ -45,7 +45,7 @@ exp_log EXP_VARARGS_DEF(int,arg1)
 	char *fmt;
 	va_list args;
 
-	force_stdout = EXP_VARARGS_START(int,arg1,args);
+	force_stdout = TCL_VARARGS_START(int,arg1,args);
 	/*va_start(args);*/
 	/*force_stdout = va_arg(args,int);*/
 	fmt = va_arg(args,char *);
@@ -82,14 +82,14 @@ int force_stdout;	/* override value of loguser */
 /* use this function for recording unusual things in the log */
 /*VARARGS*/
 void
-debuglog EXP_VARARGS_DEF(char *,arg1)
+debuglog TCL_VARARGS_DEF(char *,arg1)
 /*debuglog(va_alist)*/
 /*va_dcl*/
 {
 	char *fmt;
 	va_list args;
 
-	fmt = EXP_VARARGS_START(char *,fmt,args);
+	fmt = TCL_VARARGS_START(char *,arg1,args);
 	/*va_start(args);*/
 	/*fmt = va_arg(args,char *);*/
 	if (debugfile) vfprintf(debugfile,fmt,args);
@@ -106,14 +106,14 @@ debuglog EXP_VARARGS_DEF(char *,arg1)
 /* use this function for error conditions */
 /*VARARGS*/
 void
-exp_errorlog EXP_VARARGS_DEF(char *,arg1)
+exp_errorlog TCL_VARARGS_DEF(char *,arg1)
 /*exp_errorlog(va_alist)*/
 /*va_dcl*/
 {
 	char *fmt;
 	va_list args;
 
-	fmt = EXP_VARARGS_START(char *,arg1,args);
+	fmt = TCL_VARARGS_START(char *,arg1,args);
 	/*va_start(args);*/
 	/*fmt = va_arg(args,char *);*/
 	vfprintf(stderr,fmt,args);
@@ -173,7 +173,7 @@ enlarge_out_buffer()
 /* like sprintf, but uses a static buffer enlarged as necessary */
 /* currently supported are %s, %d, and %#d where # is a single-digit */
 void
-exp_sprintf EXP_VARARGS_DEF(char *,arg1)
+exp_sprintf TCL_VARARGS_DEF(char *,arg1)
 /* exp_sprintf(va_alist)*/
 /*va_dcl*/
 {
@@ -186,7 +186,7 @@ exp_sprintf EXP_VARARGS_DEF(char *,arg1)
 	int int_arg;
 	char *int_fmt;
 
-	fmt = EXP_VARARGS_START(char *,arg1,args);
+	fmt = TCL_VARARGS_START(char *,arg1,args);
 	/*va_start(args);*/
 	/*fmt = va_arg(args,char *);*/
 
