@@ -3,6 +3,9 @@
 #include "expect_cf.h"
 #include <stdio.h>
 #include <errno.h>
+#ifdef HAVE_INTTYPES_H
+#  include <inttypes.h>
+#endif
 #include <sys/types.h>
 
 #ifdef HAVE_UNISTD_H
@@ -22,7 +25,7 @@
 #include "exp_log.h"
 #include "exp_event.h"
 #ifdef TCL_DEBUGGER
-#include "Dbg.h"
+#include "tcldbg.h"
 #endif
 
 #ifdef __CENTERLINE__
