@@ -42,7 +42,7 @@ would appreciate credit if this program or parts of it are used.
 #include "exp_tstamp.h"	/* this should disappear when interact */
 			/* loses ref's to it */
 #ifdef TCL_DEBUGGER
-#include "Dbg.h"
+#include "tcldbg.h"
 #endif
 
 /* initial length of strings that we can guarantee patterns can match */
@@ -1545,7 +1545,7 @@ int key;
 		}
 		/* don't write to user if they're seeing it already, */
 		/* that is, typing it! */
-		if (loguser && !exp_is_stdinfd(*m))
+		if (loguser && !exp_is_stdinfd(*m) && !exp_is_devttyfd(*m))
 			fwrite(f->buffer + f->printed,
 					1,write_count,stdout);
 		if (debugfile) fwrite(f->buffer + f->printed,
